"""Top-level package for pydeck-earthengine-layers."""

__author__ = """Kyle Barron"""
__email__ = 'kyle@unfolded.ai'
__version__ = '1.2.0'

from .pydeck_earthengine_layers import (
    EarthEngineLayer, EarthEngineTerrainLayer)
